==> pcl_1.9.1+dfsg1.orig.tar.xz: pcl-pcl-1.9.1/examples/filters/example_extract_indices.cpp <==
/*
 * Software License Agreement (BSD License)
 *
 * Point Cloud Library (PCL) - www.pointclouds.org
 * Copyright (c) 2009-2011, Willow Garage, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * * Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 * * Neither the name of Willow Garage, Inc. nor the names of its
 *   contributors may be used to endorse or promote products derived
 *   from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: example_ExtractIndices.cpp 4117 2012-01-31 17:56:02Z aichim $
 *
 */

// STL
#include <iostream>

// PCL
#include <pcl/point_types.h>
#include <pcl/filters/extract_indices.h>

int
main (int, char**)
{
  typedef pcl::PointXYZ PointType;
  typedef pcl::PointCloud<PointType> CloudType;
  CloudType::Ptr cloud (new CloudType);
  cloud->is_dense = false;
  PointType p;
  for (unsigned int i = 0; i < 5; ++i)
  {
    p.x = p.y = p.z = static_cast<float> (i);
    cloud->push_back (p);
  }

  std::cout << "Cloud has " << cloud->points.size () << " points." << std::endl;

  pcl::PointIndices indices;
  indices.indices.push_back (0);
  indices.indices.push_back (2);

  pcl::ExtractIndices<PointType> extract_indices;
  extract_indices.setIndices (boost::make_shared<const pcl::PointIndices> (indices));
  extract_indices.setInputCloud (cloud);
  pcl::PointCloud<pcl::PointXYZ>::Ptr output (new pcl::PointCloud<pcl::PointXYZ>);
  extract_indices.filter (*output);

  std::cout << "Output has " << output->points.size () << " points." << std::endl;
  return (0);
}

==> pcl_1.10.0+dfsg.orig.tar.xz: pcl-pcl-1.10.0/examples/filters/example_extract_indices.cpp <==
/*
 * Software License Agreement (BSD License)
 *
 * Point Cloud Library (PCL) - www.pointclouds.org
 * Copyright (c) 2009-2011, Willow Garage, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * * Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 * * Neither the name of Willow Garage, Inc. nor the names of its
 *   contributors may be used to endorse or promote products derived
 *   from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: example_ExtractIndices.cpp 4117 2012-01-31 17:56:02Z aichim $
 *
 */

// STL
#include <iostream>

// PCL
#include <pcl/point_types.h>
#include <pcl/filters/extract_indices.h>

int
main (int, char**)
{
  using PointType = pcl::PointXYZ;
  using CloudType = pcl::PointCloud<PointType>;
  CloudType::Ptr cloud (new CloudType);
  cloud->is_dense = false;
  PointType p;
  for (unsigned int i = 0; i < 5; ++i)
  {
    p.x = p.y = p.z = static_cast<float> (i);
    cloud->push_back (p);
  }

  std::cout << "Cloud has " << cloud->points.size () << " points." << std::endl;

  pcl::PointIndices indices;
  indices.indices.push_back (0);
  indices.indices.push_back (2);

  pcl::ExtractIndices<PointType> extract_indices;
  extract_indices.setIndices (boost::make_shared<const pcl::PointIndices> (indices));
  extract_indices.setInputCloud (cloud);
  pcl::PointCloud<pcl::PointXYZ>::Ptr output (new pcl::PointCloud<pcl::PointXYZ>);
  extract_indices.filter (*output);

  std::cout << "Output has " << output->points.size () << " points." << std::endl;
  return (0);
}
